# Boots API
# www.launchpad.net/boots
# www.launchpad.net/drizzle
# boots/api/api.py
#
# ##### BEGIN LICENSE BLOCK #####
# Version: MPL 1.1
#
# The contents of this file are subject to the Mozilla Public License
# Version 1.1 (the "License"); you may not use this file except in
# compliance with the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# License for the specific language governing rights and limitations
# under the License.
#
# The Original Code is Boots Client code.
#
# The Initial Developer of the Original Code is Clark Boylan, Ken
# Brotherton, Max Goodman, Victoria Lewis, David Rosenbaum, and Andreas
# Turriff. Portions created by Clark Boylan, Ken Brotherton, Max Goodman,
# Victoria Lewis, David Rosenbaum, and Andreas Turriff are Copyright (C)
# 2009. All Rights Reserved.
#
# Contributor(s):
#
# ##### END LICENSE BLOCK #####

from drizzle import db

class Server(object):
    """Represents a connection to a database server.
    
    This object is used to execute commands on a remote server."""

    def __init__(self, hostname, port, auth):
        """Initialize a Server object.
        
        hostname should be a string.
        port should be a positive integer value.
        auth should be a dictionary possibly containing keys:
        'username', 'password', and 'database' mapping to their
        appropriate string values."""    
        self.hostname = hostname
        self.port = port
        self.auth = auth
        self._connection = None

    def connect(self):
        self._connection = db.connect(
            host     =  self.hostname,  
            port     =  self.port,
            username =  self.auth.get("username", ""),
            password =  self.auth.get("password", ""),
            database =  self.auth.get("database", ""))

    def disconnect(self):
        self._connection.close()

    @property
    def is_connected(self): 
        return self._connection is not None
    
    def execute(self, query):
        """Executes a query, returning an iterator of resulting rows."""
        cursor = self._connection.cursor()
        cursor.execute(query)
        if cursor.description:
            column_names = [column[0] for column in cursor.description]
            for row in cursor:
                yield Row(zip(column_names, row))

class Query(str):
    def substitute(self, rows): pass

class Row(dict): pass
